import 'package:flutter_test/flutter_test.dart';
import 'package:swift_travel/apis/navigation/switzerland/trias_2020.dart';

void main() {
  test(
    'test parse location response',
    () {
      final res = Trias2020Api.parseLocations(_locationQueryXmlExample);
      expect(res, hasLength(12));
      expect(res.first.id, '8501008');
      expect(res.first.label, 'Genève');
      expect(res.first.modes, hasLength(2));
      expect(res.first.modes.first.mode, 'rail');
      expect(res.first.modes.first.submode, 'unknown');
    },
  );
}

const _locationQueryXmlExample = '''
<?xml version="1.0" encoding="UTF-8"?>
<trias:Trias xmlns:siri="http://www.siri.org.uk/siri" xmlns:trias="http://www.vdv.de/trias" xmlns:acsb="http://www.ifopt.org.uk/acsb" xmlns:ifopt="http://www.ifopt.org.uk/ifopt" xmlns:datex2="http://datex2.eu/schema/1_0/1_0" version="1.1">
  <trias:ServiceDelivery>
    <siri:ResponseTimestamp>2022-02-20T10:22:18Z</siri:ResponseTimestamp>
    <siri:ProducerRef>EFAController10.4.22.1-OJP-EFA02-P</siri:ProducerRef>
    <siri:Status>true</siri:Status>
    <trias:Language>de</trias:Language>
    <trias:CalcTime>18</trias:CalcTime>
    <trias:DeliveryPayload>
      <trias:LocationInformationResponse>
        <trias:Location>
          <trias:Location>
            <trias:StopPoint>
              <trias:StopPointRef>8501008</trias:StopPointRef>
              <trias:StopPointName>
                <trias:Text>Genève</trias:Text>
                <trias:Language>de</trias:Language>
              </trias:StopPointName>
              <trias:LocalityRef>23009621:2</trias:LocalityRef>
            </trias:StopPoint>
            <trias:LocationName>
              <trias:Text>Genève</trias:Text>
              <trias:Language>de</trias:Language>
            </trias:LocationName>
            <trias:GeoPosition>
              <trias:Longitude>6.14246</trias:Longitude>
              <trias:Latitude>46.21021</trias:Latitude>
            </trias:GeoPosition>
          </trias:Location>
          <trias:Complete>true</trias:Complete>
          <trias:Probability>1</trias:Probability>
          <trias:Mode>
            <trias:PtMode>rail</trias:PtMode>
            <trias:RailSubmode>unknown</trias:RailSubmode>
          </trias:Mode>
          <trias:Mode>
            <trias:PtMode>bus</trias:PtMode>
            <trias:BusSubmode>localBus</trias:BusSubmode>
          </trias:Mode>
        </trias:Location>
        <trias:Location>
          <trias:Location>
            <trias:StopPoint>
              <trias:StopPointRef>8501237</trias:StopPointRef>
              <trias:StopPointName>
                <trias:Text>Genève CGN</trias:Text>
                <trias:Language>de</trias:Language>
              </trias:StopPointName>
              <trias:LocalityRef>23009621:2</trias:LocalityRef>
            </trias:StopPoint>
            <trias:LocationName>
              <trias:Text>Genève</trias:Text>
              <trias:Language>de</trias:Language>
            </trias:LocationName>
            <trias:GeoPosition>
              <trias:Longitude>6.14859</trias:Longitude>
              <trias:Latitude>46.20723</trias:Latitude>
            </trias:GeoPosition>
          </trias:Location>
          <trias:Complete>true</trias:Complete>
          <trias:Probability>0.959999979</trias:Probability>
          <trias:Mode>
            <trias:PtMode>water</trias:PtMode>
            <trias:WaterSubmode>unknown</trias:WaterSubmode>
          </trias:Mode>
        </trias:Location>
        <trias:Location>
          <trias:Location>
            <trias:StopPoint>
              <trias:StopPointRef>8587904</trias:StopPointRef>
              <trias:StopPointName>
                <trias:Text>Genève, OMS</trias:Text>
                <trias:Language>de</trias:Language>
              </trias:StopPointName>
              <trias:LocalityRef>23009621:2</trias:LocalityRef>
            </trias:StopPoint>
            <trias:LocationName>
              <trias:Text>Genève</trias:Text>
              <trias:Language>de</trias:Language>
            </trias:LocationName>
            <trias:GeoPosition>
              <trias:Longitude>6.13361</trias:Longitude>
              <trias:Latitude>46.23126</trias:Latitude>
            </trias:GeoPosition>
          </trias:Location>
          <trias:Complete>true</trias:Complete>
          <trias:Probability>0.959999979</trias:Probability>
          <trias:Mode>
            <trias:PtMode>bus</trias:PtMode>
            <trias:BusSubmode>localBus</trias:BusSubmode>
          </trias:Mode>
        </trias:Location>
        <trias:Location>
          <trias:Location>
            <trias:StopPoint>
              <trias:StopPointRef>8592776</trias:StopPointRef>
              <trias:StopPointName>
                <trias:Text>Genève, Gos</trias:Text>
                <trias:Language>de</trias:Language>
              </trias:StopPointName>
              <trias:LocalityRef>23009621:2</trias:LocalityRef>
            </trias:StopPoint>
            <trias:LocationName>
              <trias:Text>Genève</trias:Text>
              <trias:Language>de</trias:Language>
            </trias:LocationName>
            <trias:GeoPosition>
              <trias:Longitude>6.15474</trias:Longitude>
              <trias:Latitude>46.18790</trias:Latitude>
            </trias:GeoPosition>
          </trias:Location>
          <trias:Complete>true</trias:Complete>
          <trias:Probability>0.959999979</trias:Probability>
          <trias:Mode>
            <trias:PtMode>bus</trias:PtMode>
            <trias:BusSubmode>localBus</trias:BusSubmode>
          </trias:Mode>
        </trias:Location>
        <trias:Location>
          <trias:Location>
            <trias:StopPoint>
              <trias:StopPointRef>8592788</trias:StopPointRef>
              <trias:StopPointName>
                <trias:Text>Genève, BIT</trias:Text>
                <trias:Language>de</trias:Language>
              </trias:StopPointName>
              <trias:LocalityRef>23009621:2</trias:LocalityRef>
            </trias:StopPoint>
            <trias:LocationName>
              <trias:Text>Genève</trias:Text>
              <trias:Language>de</trias:Language>
            </trias:LocationName>
            <trias:GeoPosition>
              <trias:Longitude>6.13489</trias:Longitude>
              <trias:Latitude>46.23047</trias:Latitude>
            </trias:GeoPosition>
          </trias:Location>
          <trias:Complete>true</trias:Complete>
          <trias:Probability>0.959999979</trias:Probability>
          <trias:Mode>
            <trias:PtMode>bus</trias:PtMode>
            <trias:BusSubmode>localBus</trias:BusSubmode>
          </trias:Mode>
        </trias:Location>
        <trias:Location>
          <trias:Location>
            <trias:StopPoint>
              <trias:StopPointRef>8592914</trias:StopPointRef>
              <trias:StopPointName>
                <trias:Text>Genève, UIT</trias:Text>
                <trias:Language>de</trias:Language>
              </trias:StopPointName>
              <trias:LocalityRef>23009621:2</trias:LocalityRef>
            </trias:StopPoint>
            <trias:LocationName>
              <trias:Text>Genève</trias:Text>
              <trias:Language>de</trias:Language>
            </trias:LocationName>
            <trias:GeoPosition>
              <trias:Longitude>6.13617</trias:Longitude>
              <trias:Latitude>46.22065</trias:Latitude>
            </trias:GeoPosition>
          </trias:Location>
          <trias:Complete>true</trias:Complete>
          <trias:Probability>0.959999979</trias:Probability>
          <trias:Mode>
            <trias:PtMode>bus</trias:PtMode>
            <trias:BusSubmode>localBus</trias:BusSubmode>
          </trias:Mode>
        </trias:Location>
        <trias:Location>
          <trias:Location>
            <trias:StopPoint>
              <trias:StopPointRef>8592850</trias:StopPointRef>
              <trias:StopPointName>
                <trias:Text>Genève, Lyon</trias:Text>
                <trias:Language>de</trias:Language>
              </trias:StopPointName>
              <trias:LocalityRef>23009621:2</trias:LocalityRef>
            </trias:StopPoint>
            <trias:LocationName>
              <trias:Text>Genève</trias:Text>
              <trias:Language>de</trias:Language>
            </trias:LocationName>
            <trias:GeoPosition>
              <trias:Longitude>6.13884</trias:Longitude>
              <trias:Latitude>46.20948</trias:Latitude>
            </trias:GeoPosition>
          </trias:Location>
          <trias:Complete>true</trias:Complete>
          <trias:Probability>0.957000017</trias:Probability>
          <trias:Mode>
            <trias:PtMode>tram</trias:PtMode>
            <trias:TramSubmode>cityTram</trias:TramSubmode>
          </trias:Mode>
          <trias:Mode>
            <trias:PtMode>bus</trias:PtMode>
            <trias:BusSubmode>localBus</trias:BusSubmode>
          </trias:Mode>
        </trias:Location>
        <trias:Location>
          <trias:Location>
            <trias:StopPoint>
              <trias:StopPointRef>8592863</trias:StopPointRef>
              <trias:StopPointName>
                <trias:Text>Genève, Môle</trias:Text>
                <trias:Language>de</trias:Language>
              </trias:StopPointName>
              <trias:LocalityRef>23009621:2</trias:LocalityRef>
            </trias:StopPoint>
            <trias:LocationName>
              <trias:Text>Genève</trias:Text>
              <trias:Language>de</trias:Language>
            </trias:LocationName>
            <trias:GeoPosition>
              <trias:Longitude>6.14549</trias:Longitude>
              <trias:Latitude>46.21315</trias:Latitude>
            </trias:GeoPosition>
          </trias:Location>
          <trias:Complete>true</trias:Complete>
          <trias:Probability>0.957000017</trias:Probability>
          <trias:Mode>
            <trias:PtMode>tram</trias:PtMode>
            <trias:TramSubmode>cityTram</trias:TramSubmode>
          </trias:Mode>
          <trias:Mode>
            <trias:PtMode>bus</trias:PtMode>
            <trias:BusSubmode>localBus</trias:BusSubmode>
          </trias:Mode>
        </trias:Location>
        <trias:Location>
          <trias:Location>
            <trias:StopPoint>
              <trias:StopPointRef>8587061</trias:StopPointRef>
              <trias:StopPointName>
                <trias:Text>Genève, Rive</trias:Text>
                <trias:Language>de</trias:Language>
              </trias:StopPointName>
              <trias:LocalityRef>23009621:2</trias:LocalityRef>
            </trias:StopPoint>
            <trias:LocationName>
              <trias:Text>Genève</trias:Text>
              <trias:Language>de</trias:Language>
            </trias:LocationName>
            <trias:GeoPosition>
              <trias:Longitude>6.15281</trias:Longitude>
              <trias:Latitude>46.20186</trias:Latitude>
            </trias:GeoPosition>
          </trias:Location>
          <trias:Complete>true</trias:Complete>
          <trias:Probability>0.957000017</trias:Probability>
          <trias:Mode>
            <trias:PtMode>tram</trias:PtMode>
            <trias:TramSubmode>cityTram</trias:TramSubmode>
          </trias:Mode>
          <trias:Mode>
            <trias:PtMode>bus</trias:PtMode>
            <trias:BusSubmode>localBus</trias:BusSubmode>
          </trias:Mode>
        </trias:Location>
        <trias:Location>
          <trias:Location>
            <trias:StopPoint>
              <trias:StopPointRef>8592894</trias:StopPointRef>
              <trias:StopPointName>
                <trias:Text>Genève, Rieu</trias:Text>
                <trias:Language>de</trias:Language>
              </trias:StopPointName>
              <trias:LocalityRef>23009621:2</trias:LocalityRef>
            </trias:StopPoint>
            <trias:LocationName>
              <trias:Text>Genève</trias:Text>
              <trias:Language>de</trias:Language>
            </trias:LocationName>
            <trias:GeoPosition>
              <trias:Longitude>6.16611</trias:Longitude>
              <trias:Latitude>46.19626</trias:Latitude>
            </trias:GeoPosition>
          </trias:Location>
          <trias:Complete>true</trias:Complete>
          <trias:Probability>0.957000017</trias:Probability>
          <trias:Mode>
            <trias:PtMode>bus</trias:PtMode>
            <trias:BusSubmode>localBus</trias:BusSubmode>
          </trias:Mode>
        </trias:Location>
        <trias:Location>
          <trias:Location>
            <trias:StopPoint>
              <trias:StopPointRef>8592835</trias:StopPointRef>
              <trias:StopPointName>
                <trias:Text>Genève, Guye</trias:Text>
                <trias:Language>de</trias:Language>
              </trias:StopPointName>
              <trias:LocalityRef>23009621:2</trias:LocalityRef>
            </trias:StopPoint>
            <trias:LocationName>
              <trias:Text>Genève</trias:Text>
              <trias:Language>de</trias:Language>
            </trias:LocationName>
            <trias:GeoPosition>
              <trias:Longitude>6.12319</trias:Longitude>
              <trias:Latitude>46.20891</trias:Latitude>
            </trias:GeoPosition>
          </trias:Location>
          <trias:Complete>true</trias:Complete>
          <trias:Probability>0.957000017</trias:Probability>
          <trias:Mode>
            <trias:PtMode>bus</trias:PtMode>
            <trias:BusSubmode>localBus</trias:BusSubmode>
          </trias:Mode>
        </trias:Location>
        <trias:Location>
          <trias:Location>
            <trias:StopPoint>
              <trias:StopPointRef>8592818</trias:StopPointRef>
              <trias:StopPointName>
                <trias:Text>Genève, Dôle</trias:Text>
                <trias:Language>de</trias:Language>
              </trias:StopPointName>
              <trias:LocalityRef>23009621:2</trias:LocalityRef>
            </trias:StopPoint>
            <trias:LocationName>
              <trias:Text>Genève</trias:Text>
              <trias:Language>de</trias:Language>
            </trias:LocationName>
            <trias:GeoPosition>
              <trias:Longitude>6.13149</trias:Longitude>
              <trias:Latitude>46.20874</trias:Latitude>
            </trias:GeoPosition>
          </trias:Location>
          <trias:Complete>true</trias:Complete>
          <trias:Probability>0.957000017</trias:Probability>
          <trias:Mode>
            <trias:PtMode>bus</trias:PtMode>
            <trias:BusSubmode>localBus</trias:BusSubmode>
          </trias:Mode>
        </trias:Location>
      </trias:LocationInformationResponse>
    </trias:DeliveryPayload>
  </trias:ServiceDelivery>
</trias:Trias>
''';

// ignore: unused_element
const _stopEventReqResponse = '''
<?xml version="1.0" encoding="UTF-8"?>
<trias:Trias xmlns:siri="http://www.siri.org.uk/siri" xmlns:trias="http://www.vdv.de/trias" xmlns:acsb="http://www.ifopt.org.uk/acsb" xmlns:ifopt="http://www.ifopt.org.uk/ifopt" xmlns:datex2="http://datex2.eu/schema/1_0/1_0" version="1.1">
    <trias:ServiceDelivery>
        <siri:ResponseTimestamp>2022-02-05T12:53:52Z</siri:ResponseTimestamp>
        <siri:ProducerRef>EFAController10.4.21.6-OJP-EFA02-P</siri:ProducerRef>
        <siri:Status>true</siri:Status>
        <trias:Language>de</trias:Language>
        <trias:CalcTime>30</trias:CalcTime>
        <trias:DeliveryPayload>
            <trias:StopEventResponse>
                <trias:StopEventResponseContext>
                    <trias:Situations></trias:Situations>
                </trias:StopEventResponseContext>
                <trias:StopEventResult>
                    <trias:ResultId>ID-86B98FBA-25C1-4DCA-B257-B883CD723B5F</trias:ResultId>
                    <trias:StopEvent>
                        <trias:ThisCall>
                            <trias:CallAtStop>
                                <trias:StopPointRef>8592813</trias:StopPointRef>
                                <trias:StopPointName>
                                    <trias:Text>Genève, Crêts-de-Champel</trias:Text>
                                    <trias:Language>de</trias:Language>
                                </trias:StopPointName>
                                <trias:ServiceDeparture>
                                    <trias:TimetabledTime>2022-02-05T12:46:00Z</trias:TimetabledTime>
                                    <trias:EstimatedTime>2022-02-05T12:51:00Z</trias:EstimatedTime>
                                </trias:ServiceDeparture>
                                <trias:StopSeqNumber>25</trias:StopSeqNumber>
                            </trias:CallAtStop>
                        </trias:ThisCall>
                        <trias:OnwardCall>
                            <trias:CallAtStop>
                                <trias:StopPointRef>8592806</trias:StopPointRef>
                                <trias:StopPointName>
                                    <trias:Text>Genève, Clinique Générale</trias:Text>
                                    <trias:Language>de</trias:Language>
                                </trias:StopPointName>
                                <trias:ServiceArrival>
                                    <trias:TimetabledTime>2022-02-05T12:47:00Z</trias:TimetabledTime>
                                    <trias:EstimatedTime>2022-02-05T12:51:00Z</trias:EstimatedTime>
                                </trias:ServiceArrival>
                                <trias:ServiceDeparture>
                                    <trias:TimetabledTime>2022-02-05T12:47:00Z</trias:TimetabledTime>
                                    <trias:EstimatedTime>2022-02-05T12:52:00Z</trias:EstimatedTime>
                                </trias:ServiceDeparture>
                                <trias:StopSeqNumber>2</trias:StopSeqNumber>
                            </trias:CallAtStop>
                        </trias:OnwardCall>
                        <trias:OnwardCall>
                            <trias:CallAtStop>
                                <trias:StopPointRef>8592849</trias:StopPointRef>
                                <trias:StopPointName>
                                    <trias:Text>Genève, Aubert</trias:Text>
                                    <trias:Language>de</trias:Language>
                                </trias:StopPointName>
                                <trias:ServiceArrival>
                                    <trias:TimetabledTime>2022-02-05T12:47:00Z</trias:TimetabledTime>
                                    <trias:EstimatedTime>2022-02-05T12:52:00Z</trias:EstimatedTime>
                                </trias:ServiceArrival>
                                <trias:ServiceDeparture>
                                    <trias:TimetabledTime>2022-02-05T12:47:00Z</trias:TimetabledTime>
                                    <trias:EstimatedTime>2022-02-05T12:52:00Z</trias:EstimatedTime>
                                </trias:ServiceDeparture>
                                <trias:StopSeqNumber>3</trias:StopSeqNumber>
                            </trias:CallAtStop>
                        </trias:OnwardCall>
                        <trias:OnwardCall>
                            <trias:CallAtStop>
                                <trias:StopPointRef>8592894</trias:StopPointRef>
                                <trias:StopPointName>
                                    <trias:Text>Genève, Rieu</trias:Text>
                                    <trias:Language>de</trias:Language>
                                </trias:StopPointName>
                                <trias:ServiceArrival>
                                    <trias:TimetabledTime>2022-02-05T12:49:00Z</trias:TimetabledTime>
                                    <trias:EstimatedTime>2022-02-05T12:53:00Z</trias:EstimatedTime>
                                </trias:ServiceArrival>
                                <trias:ServiceDeparture>
                                    <trias:TimetabledTime>2022-02-05T12:49:00Z</trias:TimetabledTime>
                                    <trias:EstimatedTime>2022-02-05T12:53:00Z</trias:EstimatedTime>
                                </trias:ServiceDeparture>
                                <trias:StopSeqNumber>4</trias:StopSeqNumber>
                            </trias:CallAtStop>
                        </trias:OnwardCall>
                        <trias:OnwardCall>
                            <trias:CallAtStop>
                                <trias:StopPointRef>8592778</trias:StopPointRef>
                                <trias:StopPointName>
                                    <trias:Text>Genève, Amandolier</trias:Text>
                                    <trias:Language>de</trias:Language>
                                </trias:StopPointName>
                                <trias:ServiceArrival>
                                    <trias:TimetabledTime>2022-02-05T12:51:00Z</trias:TimetabledTime>
                                    <trias:EstimatedTime>2022-02-05T12:55:00Z</trias:EstimatedTime>
                                </trias:ServiceArrival>
                                <trias:ServiceDeparture>
                                    <trias:TimetabledTime>2022-02-05T12:51:00Z</trias:TimetabledTime>
                                    <trias:EstimatedTime>2022-02-05T12:55:00Z</trias:EstimatedTime>
                                </trias:ServiceDeparture>
                                <trias:StopSeqNumber>5</trias:StopSeqNumber>
                            </trias:CallAtStop>
                        </trias:OnwardCall>
                        <trias:OnwardCall>
                            <trias:CallAtStop>
                                <trias:StopPointRef>8592829</trias:StopPointRef>
                                <trias:StopPointName>
                                    <trias:Text>Genève-Eaux-Vives, gare</trias:Text>
                                    <trias:Language>de</trias:Language>
                                </trias:StopPointName>
                                <trias:ServiceArrival>
                                    <trias:TimetabledTime>2022-02-05T12:52:00Z</trias:TimetabledTime>
                                    <trias:EstimatedTime>2022-02-05T12:57:00Z</trias:EstimatedTime>
                                </trias:ServiceArrival>
                                <trias:StopSeqNumber>6</trias:StopSeqNumber>
                            </trias:CallAtStop>
                        </trias:OnwardCall>
                        <trias:Service>
                            <trias:OperatingDayRef>2022-02-05</trias:OperatingDayRef>
                            <trias:JourneyRef>ojp:92011::H:j22:322:9759</trias:JourneyRef>
                            <trias:LineRef>ojp:92011::H</trias:LineRef>
                            <trias:DirectionRef>outward</trias:DirectionRef>
                            <trias:Mode>
                                <trias:PtMode>bus</trias:PtMode>
                                <trias:BusSubmode>localBus</trias:BusSubmode>
                                <trias:Name>
                                    <trias:Text>Bus</trias:Text>
                                    <trias:Language>de</trias:Language>
                                </trias:Name>
                            </trias:Mode>
                            <trias:PublishedLineName>
                                <trias:Text>11</trias:Text>
                                <trias:Language>de</trias:Language>
                            </trias:PublishedLineName>
                            <trias:OperatorRef>ojp:881</trias:OperatorRef>
                            <trias:OriginStopPointRef>8592843</trias:OriginStopPointRef>
                            <trias:OriginText>
                                <trias:Text>Genève, Jardin Botanique</trias:Text>
                                <trias:Language>de</trias:Language>
                            </trias:OriginText>
                            <trias:DestinationStopPointRef>8592829</trias:DestinationStopPointRef>
                            <trias:DestinationText>
                                <trias:Text>Genève-Eaux-Vives, gare</trias:Text>
                                <trias:Language>de</trias:Language>
                            </trias:DestinationText>
                        </trias:Service>
                    </trias:StopEvent>
                </trias:StopEventResult>
            </trias:StopEventResponse>
        </trias:DeliveryPayload>
    </trias:ServiceDelivery>
</trias:Trias>
''';
